@@ -40,6 +40,11 @@ int main( int argc, char** argv ) {
     cout << "        return " << Qt::Key_Minus << ";\n" ;
     cout << "    case GDK_equal :\n" ;
     cout << "        return " << Qt::Key_Equal << ";\n" ;
+    cout << "    case GDK_comma :\n" ;
+    cout << "        return " << Qt::Key_Comma << ";\n" ;
+    cout << "    case GDK_period :\n" ;
+    cout << "        return " << Qt::Key_Period << ";\n" ;
+
     cout << "    case 65421 :\n" ;
     cout << "        return " << Qt::Key_Enter << ";\n" ;
     cout << "    case 65507 :\n" ;
@@ -56,6 +61,42 @@ int main( int argc, char** argv ) {
     cout << "        return " << 16777236 << ";\n" ; // n900_right
     cout << "    case 65362 :\n" ;
     cout << "        return " << 16777235 << ";\n" ; // n900_up
+
+    cout << "    case GDK_asterisk :\n" ;
+    cout << "        return " << Qt::Key_Asterisk << ";\n" ;
+    cout << "    case GDK_plus :\n" ;
+    cout << "        return " << Qt::Key_Plus << ";\n" ;
+    cout << "    case GDK_numbersign :\n" ;
+    cout << "        return " << Qt::Key_NumberSign << ";\n" ;
+    //cout << "    case GDK_minus :\n" ;
+    //cout << "        return " << Qt::Key_Minus << ";\n" ;
+    cout << "    case GDK_parenleft :\n" ;
+    cout << "        return " << Qt::Key_ParenLeft << ";\n" ;
+    cout << "    case GDK_parenright :\n" ;
+    cout << "        return " << Qt::Key_ParenRight << ";\n" ;
+    cout << "    case GDK_ampersand :\n" ;
+    cout << "        return " << Qt::Key_Ampersand << ";\n" ;
+    cout << "    case GDK_exclam :\n" ;
+    cout << "        return " << Qt::Key_Exclam << ";\n" ;
+    cout << "    case GDK_question :\n" ;
+    cout << "        return " << Qt::Key_Question << ";\n" ;
+    cout << "    case 163 :\n" ;
+    cout << "        return " << 163 << ";\n" ;
+    cout << "    case GDK_dollar :\n" ;
+    cout << "        return " << Qt::Key_Dollar << ";\n" ;
+    cout << "    case 8364 :\n" ;
+    cout << "        return " << 8364 << ";\n" ;
+    cout << "    case GDK_slash :\n" ;
+    cout << "        return " << Qt::Key_Slash << ";\n" ;
+    cout << "    case GDK_backslash :\n" ;
+    cout << "        return " << Qt::Key_Backslash << ";\n" ;
+    cout << "    case GDK_quotedbl :\n" ;
+    cout << "        return " << Qt::Key_QuoteDbl << ";\n" ;
+    cout << "    case GDK_apostrophe :\n" ;
+    cout << "        return " << Qt::Key_Apostrophe << ";\n" ;
+    cout << "    case GDK_at :\n" ;
+    cout << "        return " << Qt::Key_At << ";\n" ;
+
     cout << "    default :\n" ;
     cout << "        return -1 ;\n" ;
     cout << "    }\n" ;
