@@ -4,6 +4,10 @@
 #include <QDeclarativeView>
 #include <QSize>
 
+namespace adaptor {
+class Adaptor ;
+}
+
 namespace extra {
 
 class ExtraInputPanel : public QDeclarativeView {
@@ -11,6 +15,8 @@ class ExtraInputPanel : public QDeclarativeView {
 
     Q_PROPERTY( int rotate READ readRotate WRITE writeRotate NOTIFY rotateChanged ) 
 
+friend class adaptor::Adaptor ;
+
 signals :
     //void candidateUpdate() ;
     void replaceSurrounding( const QString& text ) ;
