@@ -12,7 +12,8 @@ class Host ;
 
 namespace handle {
 
-//enum Modifiers { NoModifier = 1, CtrlModifier = 2, FnModifier = 4, ShiftModifier = 8 } ;
+enum Modifier { NoModifier = 0, CtrlModifier = 1, FnModifier = 2, ShiftModifier = 4 } ;
+Q_DECLARE_FLAGS( Modifiers, Modifier )
 
 class Handle : public QObject {
     Q_OBJECT 
@@ -21,8 +22,14 @@ signals :
 public :
     host::Host* host ;
     engine::Engine* engine ;
-    //Modifiers modifiers ;
+    Modifiers modifiers ;
     int pressCount ;
+#ifdef Q_WS_MAEMO_5
+    //int fnPressCount ;
+    //int shiftPressCount ;
+    bool fnPressed ;
+    bool shiftPressed ;
+#endif
 
     Handle( host::Host* host, engine::Engine* engine, QObject* parent = NULL ) ;
     Q_INVOKABLE bool processKeyPress( int keycode ) ;
@@ -31,6 +38,8 @@ public :
     Q_INVOKABLE void setKeyboardLayout( int layout ) ;
 } ;
 
+Q_DECLARE_OPERATORS_FOR_FLAGS( Modifiers )
+
 } 
 
 
